@@ -10,13 +10,14 @@
 */
 
 var java = require('java');
-var logger = require('winston');
+//var logger = require('winston');
 var async = require('async');
-const config = require(process.cwd() + '/config/config');
+//const config = require(process.cwd() + '/config/config');
 
 var jdbc;
 module.exports = function (app) {
-
+    var config=app.nylon.config;
+    var logger=app.nylon.logger;
     var jdbc_function = {
         query: function (driver, sql, parameters, callback) {
 
@@ -54,14 +55,14 @@ module.exports = function (app) {
         }
     }
 
-    app.use(function (req, res, next) {
+    //app.use(function (req, res, next) {
 
-        req.jdbc = jdbc_function;
-        next();
+    //    req.jdbc = jdbc_function;
+     //   next();
 
-    });
+    //});
 
-    app.nylon.jdbc=jdbc_function;
+    app.nylon.req.jdbc=jdbc_function;
 
   
 
