@@ -116,12 +116,14 @@ module.exports = function (app) {
 
     fscan.scan(app.nylon.work_dir + route_dir, ".routes.js", true, function (err, routes) {
         loadRouter(app, "/api", app.nylon.work_dir, route_dir, routes, function (err, app) {
+
             app.get('/*', prpl.makeHandler('./public', {
                 builds: [
-                    { name: 'modern', browserCapabilities: ['es2015', 'push'] },
-                    { name: 'fallback' },
+                    { name: '.', browserCapabilities: ['es2015', 'push'] },
+                    { name: '.' },
                 ],
             }));
+
         });
     });
 
